var DP_Game_SelectList = {
    dir: 'res/game/_select_list/'
};

function DP_DiningRoom_SelectList() {
    this.baseImage = null;
    this.items = [null, null, null];
    this.itemBGImages = [null, null, null];
    this.movePos = {
        from: null,
        to: null,
        time: null
    }
}

// 设置背景图 所有node的父节点
DP_DiningRoom_SelectList.prototype.setBaseImage = function (parent, dir, name, pos) {
    if (!this.baseImage) {
        this.baseImage = zNewSpriteCreate(dir, name, parent);
    } else {
        zSetSpriteTexture(dir, name, this.baseImage);
    }
    if (pos) {
        this.baseImage.setPosition(pos);
    }
};
DP_DiningRoom_SelectList.prototype.setBaseImageLocalZOrder = function (zOrder) {
    if (this.baseImage) {
        this.baseImage.setLocalZOrder(zOrder);
    }
};
// 设置入场方式 起点、终点、时间
DP_DiningRoom_SelectList.prototype.setMovePos = function (from, to, time) {
    this.movePos.from = from;
    this.movePos.to = to;
    this.movePos.time = time;
};
// 入场
DP_DiningRoom_SelectList.prototype.into = function () {
    this.baseImage.stopAllActions();
    this.baseImage.setPosition(this.movePos.from);
    this.baseImage.runAction(cc.moveTo(this.movePos.time, this.movePos.to).easing(cc.easeIn(2)));
    this.baseImage.scheduleOnce(() => {
        this.tip();
    }, 0.5);
};
// 出场
DP_DiningRoom_SelectList.prototype.out = function () {
    this.baseImage.stopAllActions();
    this.baseImage.setPosition(this.movePos.to);
    this.baseImage.runAction(cc.moveTo(this.movePos.time, this.movePos.from).easing(cc.easeOut(2)));
    this.stopTip();
};
// 提示点击列表选项
DP_DiningRoom_SelectList.prototype.tip = function () {
    // zLog('select tip');
    tip_hand = zAddTipHand(this.baseImage);
    tip_hand.autoTipAction(cc.p(165.70, 448.70));
    this.tip_hand = tip_hand;
    // zAddTouchLogPosEvent(tip_hand, true);
};
DP_DiningRoom_SelectList.prototype.stopTip = function () {
    if (this.tip_hand) {
        this.baseImage.removeChild(this.tip_hand);
        this.tip_hand = null;
    }
};
// 设置背景图位置
DP_DiningRoom_SelectList.prototype.setBaseImagePosition = function (pos) {
    this.baseImage.setPosition(pos);
};
// 获取背景图
DP_DiningRoom_SelectList.prototype.getBaseImage = function () {
    return this.baseImage;
};
// 设置每一项背景
DP_DiningRoom_SelectList.prototype.setItemBGImage = function (dir, name) {
    for (var i = 0; i < 3; i++) {
        if (!this.itemBGImages[i]) {
            this.itemBGImages[i] = zNewSpriteCreate(dir, name, this.baseImage);
            this.itemBGImages[i].setPosition(this.baseImage.width / 2 + 10, this.baseImage.height / 2 + (this.itemBGImages[i].height + 20) * -(i - 1));
        }
    }
};
// 设置每一项
DP_DiningRoom_SelectList.prototype.setItem = function (dir, name, itemIdx) {
    if (!this.items[itemIdx]) {
        var item = zNewSpriteCreate(dir, name, this.baseImage);
        var item_bg = this.itemBGImages[itemIdx];
        item.setPosition(item_bg.getPosition());
        item.idx = itemIdx;
        item.setName(name);
        item.setScale(item.width > item.height ? item_bg.width * 0.8 / item.width : item_bg.height * 0.8 / item.height);
        this.items[itemIdx] = item;
    } else {
        zSetSpriteTexture(dir, name, this.items[itemIdx]);
        var item_bg = this.itemBGImages[itemIdx];
        var item = this.items[itemIdx];
        item.setName(name);
        item.setScale(item.width > item.height ? item_bg.width * 0.8 / item.width : item_bg.height * 0.8 / item.height);
    }
    item.backScale = item.getScale();
    // zLog('idx : ', itemIdx, ' , backScale : ', item.backScale.toFixed(2));
    this.items[itemIdx].setVisible(true);
    this.resumeItemEvent(itemIdx);
};
DP_DiningRoom_SelectList.prototype.getItem = function (idx) {
    return this.items[idx];
};
// 设置指定项事件
DP_DiningRoom_SelectList.prototype.setItemEvent = function (listener, itemIdx) {
    zSetNodeEvent(listener, this.items[itemIdx]);
};
// 暂停指定项事件
DP_DiningRoom_SelectList.prototype.pauseItemEvent = function (itemIdx) {
    zPauseTargetEvent(this.items[itemIdx]);
};
// 恢复指定项事件
DP_DiningRoom_SelectList.prototype.resumeItemEvent = function (itemIdx) {
    zResumeTargetEvent(this.items[itemIdx]);
};
// 暂停指定项之外的事件
DP_DiningRoom_SelectList.prototype.pauseOtherItemEvent = function (itemIdx) {
    for (var i = 0; i < 3; ++i) {
        if (itemIdx != i) {
            zPauseTargetEvent(this.items[i]);
        }
    }
};
// 恢复指定项之外的事件
DP_DiningRoom_SelectList.prototype.resumeOtherItemEvent = function (itemIdx) {
    for (var i = 0; i < 3; ++i) {
        if (itemIdx != i) {
            zResumeTargetEvent(this.items[i]);
        }
    }
};
// 把指定项放回原处 并设置是否可见
DP_DiningRoom_SelectList.prototype.setItemBackPos = function (itemIdx, isVisible) {
    this.items[0].setVisible(true);
    this.items[1].setVisible(true);
    this.items[2].setVisible(true);
    this.items[itemIdx].setLocalZOrder(0);
    this.items[itemIdx].setPosition(this.itemBGImages[itemIdx].getPosition());
    this.items[itemIdx].setVisible(isVisible !== undefined ? isVisible : true);
};
// 通过缩放到0隐藏指定项
DP_DiningRoom_SelectList.prototype.scaleHideItem = function (itemIdx) {
    this.items[itemIdx].setScale(0);
};
// 通过缩放到合适大小显示指定项
DP_DiningRoom_SelectList.prototype.scaleShowItem = function (itemIdx) {
    this.items[itemIdx].setScale(this.items[itemIdx].backScale);
};
DP_DiningRoom_SelectList.prototype.scaleShowOtherItem = function (itemIdx) {
    for (var i = 0; i < this.items.length; ++i) {
        if (i != itemIdx) {
            this.items[i].setScale(this.items[i].backScale);
        }
    }
};
// 隐藏整个列表
DP_DiningRoom_SelectList.prototype.hide = function () {
    this.baseImage.setVisible(false);
};
// 显示整个列表
DP_DiningRoom_SelectList.prototype.show = function () {
    this.baseImage.setVisible(true);
};
// 暂停全部事件
DP_DiningRoom_SelectList.prototype.pauseEvent = function () {
    zPauseTargetEvent(this.baseImage, true);
};
// 恢复全部事件
DP_DiningRoom_SelectList.prototype.resumeEvent = function () {
    zResumeTargetEvent(this.baseImage, true);
};
// 移动指定项到指定位置 并执行完成后回调
DP_DiningRoom_SelectList.prototype.moveItemBezierTo = function (itemIdx, endWorldPos, callBack, target, argus, isResumeAll) {
    var self = this;
    var item = this.items[itemIdx];
    var p1 = item.getPosition();
    var p2 = this.baseImage.convertToNodeSpace(endWorldPos);
    var bezier = [p1, cc.p((p1.x + p2.x) / 2, Math.max(p1.y, p2.y) + 100), p2];
    ddSound.playEffect('game_all_fly');
    item.runAction(cc.sequence(
        cc.bezierTo(0.5, bezier).easing(cc.easeOut(2)),
        cc.callFunc(function () {
            if (isResumeAll) {
                self.resumeEvent();
                self.setItemBackPos(itemIdx, true);
            } else {
                self.resumeOtherItemEvent(itemIdx);
                self.pauseItemEvent(itemIdx);
                self.setItemBackPos(itemIdx, false);
            }
            if (argus.c) {
                callBack.call(target, argus.a, argus.b, argus.c);
            } else if (argus.b) {
                callBack.call(target, argus.a, argus.b);
            } else if (argus.a) {
                callBack.call(target, argus.a);
            }

        })
    ));
};

// 添加右侧列表
function zAddSelectList(parent, baseImage, movePos, itemBG, item, itemListener) {
    var select_list = new DP_DiningRoom_SelectList();
    select_list.setBaseImage(parent, DP_Game_SelectList.dir, baseImage.name, movePos.from);
    if (baseImage.zOrder) {
        select_list.setBaseImageLocalZOrder(baseImage.zOrder);
    }
    select_list.setMovePos(movePos.from, cc.p(542.16 + (isFullScreenDevice() ? 65 : 0), 451.40), movePos.time);
    select_list.setItemBGImage(DP_Game_SelectList.dir, itemBG.name);
    for (var i = 0; i < 3; ++i) {
        // zLog(item.dir + item.name[i]);
        select_list.setItem(item.dir, item.name[i], i);
        select_list.setItemEvent(itemListener.clone(), i);
    }
    return select_list;
}

//** **//
//          确认按钮
//** **//

function DP_DiningRoom_ButtonOK() {
    this.baseImage = null;
    this.movePos = {
        from: null,
        to: null,
        time: null
    }
}

DP_DiningRoom_ButtonOK.prototype.setBaseImage = function (parent, dir, name, pos) {
    if (!this.baseImage) {
        this.baseImage = zNewSpriteCreate(dir, name, parent);
        // zAddTouchLogPosEvent(this.baseImage);
    } else {
        zSetSpriteTexture(dir, name, this.baseImage);
    }
    this.baseImage.setPosition(pos);
};
DP_DiningRoom_ButtonOK.prototype.setBaseImagePosition = function (pos) {
    this.baseImage.setPosition(pos);
};
DP_DiningRoom_ButtonOK.prototype.setMovePos = function (from, to, time) {
    this.movePos.from = from;
    this.movePos.to = to;
    this.movePos.time = time;
};
DP_DiningRoom_ButtonOK.prototype.setEventCallBack = function (callback, who) {
    var listener = zNewEventListenerCreate(function (touch, target) {
        zPauseTargetEvent(target, true);
        callback.call(who);
    }, null, null, null);
    zSetNodeEvent(listener, this.baseImage);
};
DP_DiningRoom_ButtonOK.prototype.into = function () {
    if (cc.pDistance(this.baseImage.getPosition(), this.movePos.to) <= 0) {
        // zLog('already into');
        this.baseImage.runAction(cc.sequence(
            cc.scaleTo(0.1, 1.2).easing(cc.easeIn(2)),
            cc.scaleTo(0.1, 0.8).easing(cc.easeOut(2)),
            cc.scaleTo(0.1, 1.1).easing(cc.easeIn(2)),
            cc.scaleTo(0.1, 0.9).easing(cc.easeOut(2)),
            cc.scaleTo(0.1, 1).easing(cc.easeInOut(2))
        ));
        return;
    }
    zPauseTargetEvent(this.baseImage, true);
    this.baseImage.stopAllActions();
    this.baseImage.setPosition(this.movePos.from);
    this.baseImage.runAction(cc.sequence(
        cc.moveTo(this.movePos.time, this.movePos.to),
        cc.callFunc(() => {
            zResumeTargetEvent(this.baseImage, true);
        })
    ));
};
DP_DiningRoom_ButtonOK.prototype.out = function () {
    if (cc.pDistance(this.baseImage.getPosition(), this.movePos.from) <= 0) {
        return;
    }
    this.baseImage.stopAllActions();
    this.baseImage.setPosition(this.movePos.to);
    this.baseImage.runAction(cc.moveTo(this.movePos.time, this.movePos.from));
    zPauseTargetEvent(this.baseImage, true);
    // zLog('out : ');
};

function zAddDiningRoomButtonOK(parent, x) {
    var isPhone = !isPad();
    var btn_ok = new DP_DiningRoom_ButtonOK();
    var from = cc.p(x == undefined ? 302.30 : x, cc.winSize.height - (Global_DP.sinkY + 80) + 300);
    var to = cc.p(x == undefined ? 302.30 : x, cc.winSize.height - (Global_DP.sinkY + 80) + (isPhone ? 110 : 0));
    btn_ok.setBaseImage(parent, Global_DP_Button.dir, 'btn_ok_long', from);
    btn_ok.setMovePos(from, to, 0.5);
    return btn_ok;
};

function zAddDiningRoomButtonOKLeft(parent, x) {
    var isPhone = !isPad();
    var btn_ok = new DP_DiningRoom_ButtonOK();
    var from = cc.p(x == undefined ? -372.30 : x, cc.winSize.height - (Global_DP.sinkY + 80) + 300);
    var to = cc.p(x == undefined ? -372.30 : x, cc.winSize.height - (Global_DP.sinkY + 80) + (isPhone ? 110 : 0));
    btn_ok.setBaseImage(parent, Global_DP_Button.dir, 'btn_ok_long', from);
    btn_ok.setMovePos(from, to, 0.5);
    return btn_ok;
};

//** **//
//
//** **//

var DP_DiningRoom_Tray = cc.Node.extend({
    baseImage: null,
    movePos: {
        from: null,
        to: null,
        time: null
    },
    ctor: function () {
        this._super();
    },
    setBaseImage: function (dir, name, parent, pos) {
        if (!this.baseImage) {
            this.baseImage = zNewSpriteCreate(dir, name, parent);
            // zAddTouchLogPosEvent(this.baseImage);
        } else {
            zSetSpriteTexture(dir, name, this.baseImage);
        }
        this.baseImage.setPosition(pos);
    },
    setMovePos: function (from, to, time) {
        this.movePos.from = from;
        this.movePos.to = to;
        this.movePos.time = time;
    },
    into: function () {
        this.baseImage.stopAllActions();
        this.baseImage.setPosition(this.movePos.from);
        this.baseImage.runAction(cc.moveTo(this.movePos.time, this.movePos.to).easing(cc.easeIn(2)));
    },
    out: function () {
        this.baseImage.stopAllActions();
        this.baseImage.setPosition(this.movePos.to);
        this.baseImage.runAction(cc.moveTo(this.movePos.time, this.movePos.from).easing(cc.easeOut(2)));
    }
});

function zAddDiningRoomTray(parent) {
    var tray = new DP_DiningRoom_Tray();
    parent.addChild(tray);
    tray.setBaseImage(Global_DP_DiningRoom.dir, 'tray', parent, cc.p(-cc.winSize.width / 2 - 350, 240.80));
    tray.setMovePos(cc.p(-cc.winSize.width / 2 - 350, 240.80), cc.p(-651.98, 240.80), 0.5);
    return tray;
}